@@ -45,7 +45,7 @@ class PubSubPublisher(object):
         # msg = json.dumps(msg_dict, sort_keys=True, default=default_object)
         # ret = self._client.publish(self._topic, msg.encode(), **self._msg_kwargs).result()
         msg = json.dumps(msg_dict, sort_keys=True, default=default_object)
-        attr_data = json.dumps(**self._msg_kwargs, default=default_object)
+        attr_data = json.dumps(self._msg_kwargs, default=default_object)
         ret = self._client.publish(self._topic, msg.encode(), attr_data).result()
 
         self._messages.clear()
